@@ -1,7 +1,6 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
-#    Copyright (C) 2011-2020 Luis Falcon <falcon@gnuhealth.org>
-#    Copyright (C) 2011-2020 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2011-2021 Luis Falcon <falcon@gnuhealth.org>
+#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
 #    Copyright (C) 2011 Cédric Krier
 
 #    This program is free software: you can redistribute it and/or modify
@@ -22,8 +21,10 @@ import re
 import os
 import configparser
 
+
 def read(fname):
-    return open(os.path.join(os.path.dirname(__file__), fname), encoding="UTF-8").read()
+    return open(os.path.join(os.path.dirname(__file__), fname)).read()
+
 
 config = configparser.ConfigParser()
 config.readfp(open('tryton.cfg'))
@@ -34,29 +35,32 @@ for key in ('depends', 'extras_depend', 'xml'):
         info[key] = info[key].strip().splitlines()
 major_version, minor_version = 5, 0
 
-requires = ['pytz','numpy','matplotlib']
+requires = ['pytz', 'numpy']
 
 for dep in info.get('depends', []):
     if (dep == 'health'):
         requires.append('gnuhealth == %s' % (info.get('version')))
 
     elif dep.startswith('health_'):
-        health_package = dep.split('_',1)[1]
+        health_package = dep.split('_', 1)[1]
         requires.append('gnuhealth_%s == %s' %
-            (health_package, info.get('version')))
-    else: 
+                        (health_package, info.get('version')))
+    else:
         if not re.match(r'(ir|res|webdav)(\W|$)', dep):
             requires.append('trytond_%s >= %s.%s, < %s.%s' %
-                (dep, major_version, minor_version, major_version,
-                    minor_version + 1))
+                            (dep, major_version, minor_version, major_version,
+                             minor_version + 1))
 
 requires.append('trytond >= %s.%s, < %s.%s' %
-    (major_version, minor_version, major_version, minor_version + 1))
+                (major_version, minor_version, major_version,
+                 minor_version + 1))
 
-setup(name='gnuhealth',
+setup(
+    name='gnuhealth',
     version=info.get('version', '0.0.1'),
-    description=info.get('description', 'GNU Health - The Free/Libre Hospital and Health Information System'),
-    long_description=read('README'),
+    description=info.get('description', 'GNU Health HMIS: Hospital and Health'
+                         ' Information System'),
+    long_description=read('README.rst'),
     author='GNU Solidario',
     author_email='health@gnusolidario.org',
     url='https://www.gnuhealth.org',
@@ -70,10 +74,10 @@ setup(name='gnuhealth',
         ],
 
     package_data={
-        'trytond.modules.health': info.get('xml', []) \
-            + info.get('translation', []) \
-            + ['tryton.cfg', 'view/*.xml', 'doc/*.rst', 'locale/*.po',
-               'report/*.odt', 'icons/*.svg'],
+        'trytond.modules.health': info.get('xml', []) +
+        info.get('translation', []) +
+        ['tryton.cfg', 'view/*.xml', 'doc/*.rst',
+            'locale/*.po', 'report/*.fodt', 'icons/*.svg'],
         },
 
     classifiers=[
@@ -102,4 +106,4 @@ setup(name='gnuhealth',
     """,
     test_suite='tests',
     test_loader='trytond.test_loader:Loader',
-    )
+)
