@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2020 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2020 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2021 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -671,13 +671,14 @@ class GnuHealthPatient(ModelSQL, ModelView):
                 counter=counter+1
             return stillbirths
 
-
     @classmethod
     def view_attributes(cls):
-        return [('//page[@id="page_gyneco_obs"]', 'states', {
+        return super(GnuHealthPatient, cls).view_attributes() + [
+                ('//page[@id="page_gyneco_obs"]', 'states', {
                 'invisible': Equal(Eval('biological_sex'), 'm'),
                 })]
 
+
 class PatientMenstrualHistory(ModelSQL, ModelView):
     'Menstrual History'
     __name__ = 'gnuhealth.patient.menstrual_history'
