@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2019 Luis Falcon <falcon@gnuhealth.org>
-#    Copyright (C) 2011-2019 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2021 Luis Falcon <falcon@gnuhealth.org>
+#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -27,12 +27,12 @@ from trytond.transaction import Transaction
 from trytond.pool import Pool
 from trytond import backend
 from trytond.tools.multivalue import migrate_property
-
+from trytond.pyson import Eval, Not, Bool, PYSONEncoder, Equal, And, Or, If
 
 __all__ = ['GnuHealthSequences', 'GnuHealthSequenceSetup',
     'PatientData', 'TestType', 'Lab',
     'GnuHealthLabTestUnits', 'GnuHealthTestCritearea',
-    'GnuHealthPatientLabTest']
+    'GnuHealthPatientLabTest','PatientHealthCondition']
 
 sequences = ['lab_sequence', 'lab_request_sequence']
 
@@ -80,7 +80,7 @@ class GnuHealthSequenceSetup(ModelSQL, ValueMixin):
     lab_sequence = fields.Many2One('ir.sequence', 
         'Lab Result Sequence', required=True,
         domain=[('code', '=', 'gnuhealth.lab')])
-  
+
     @classmethod
     def __register__(cls, module_name):
         TableHandler = backend.get('TableHandler')
@@ -112,7 +112,7 @@ class GnuHealthSequenceSetup(ModelSQL, ValueMixin):
         ModelData = pool.get('ir.model.data')
         return ModelData.get_id(
             'health_lab', 'seq_gnuhealth_lab_test')
-    
+
 # END SEQUENCE SETUP , MIGRATION FROM FIELDS.MultiValue
 
 
@@ -194,6 +194,10 @@ class Lab(ModelSQL, ModelView):
     date_analysis = fields.DateTime('Date of the Analysis', select=True)
     request_order = fields.Integer('Request', readonly=True)
 
+    pathology = fields.Many2One(
+        'gnuhealth.pathology', 'Pathology',
+        help='Pathology confirmed / associated to this lab test.')
+
     analytes_summary = \
         fields.Function(fields.Text('Summary'),
          'get_analytes_summary')
@@ -344,7 +348,7 @@ class GnuHealthTestCritearea(ModelSQL, ModelView):
 class GnuHealthPatientLabTest(ModelSQL, ModelView):
     'Patient Lab Test'
     __name__ = 'gnuhealth.patient.lab.test'
-    
+
     name = fields.Many2One('gnuhealth.lab.test_type', 'Test Type',
         required=True, select=True)
     date = fields.DateTime('Date', select=True)
@@ -415,3 +419,18 @@ class GnuHealthPatientLabTest(ModelSQL, ModelView):
         default['date'] = cls.default_date()
         return super(GnuHealthPatientLabTest, cls).copy(tests,
             default=default)
+
+class PatientHealthCondition(ModelSQL, ModelView):
+    'Patient Conditions History'
+    __name__ = 'gnuhealth.patient.disease'
+
+    # Adds lab confirmed and the link to the test to the
+    # Patient health Condition
+
+    lab_confirmed = fields.Boolean('Lab Confirmed', help='Confirmed by'
+        ' laboratory test')
+
+    lab_test = fields.Many2One('gnuhealth.lab','Lab Test',
+        domain=[('patient', '=', Eval('name'))], depends=['name'],
+        states={'invisible': Not(Bool(Eval('lab_confirmed')))},
+        help='Lab test that confirmed the condition')
