@@ -1,6 +1,5 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
-#    Copyright (C) 2011-2020 Luis Falcon <falcon@gnuhealth.org>
+#    Copyright (C) 2011-2021 Luis Falcon <falcon@gnuhealth.org>
 #    Copyright (C) 2011 Cédric Krier
 
 #    This program is free software: you can redistribute it and/or modify
@@ -22,7 +21,7 @@ import os
 import configparser
 
 def read(fname):
-    return open(os.path.join(os.path.dirname(__file__), fname), encoding="UTF-8").read()
+    return open(os.path.join(os.path.dirname(__file__), fname)).read()
 
 config = configparser.ConfigParser()
 config.readfp(open('tryton.cfg'))
@@ -67,7 +66,7 @@ setup(name='gnuhealth_lab',
         'trytond.modules.health_lab': info.get('xml', []) \
             + info.get('translation', []) \
             + ['tryton.cfg', 'view/*.xml', 'doc/*.rst', 'locale/*.po',
-               'report/*.odt', 'icons/*.svg'],
+               'report/*.fodt', 'icons/*.svg'],
         },
     classifiers=[
         'Development Status :: 5 - Production/Stable',
