@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2020 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2020 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2021 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -64,12 +64,11 @@ class PatientSESAssessment(ModelSQL, ModelView):
 
     assessment_date = fields.DateTime('Date', help="Assessment date",
         states = STATES)
-        
+
     computed_age = fields.Function(fields.Char(
             'Age',
             help="Computed patient age at the moment of the evaluation"),
             'patient_age_at_assessment')
-            
     health_professional = fields.Many2One(
         'gnuhealth.healthprofessional', 'Health Professional', readonly=True,
         help="Health professional"
@@ -229,7 +228,7 @@ class PatientSESAssessment(ModelSQL, ModelView):
         occupation=education=du=housing=None
         if (self.patient and self.patient.name.occupation):
             occupation = self.patient.name.occupation
-        
+
         if (self.patient and self.patient.name.education):
             education = self.patient.name.education
 
@@ -259,7 +258,6 @@ class PatientSESAssessment(ModelSQL, ModelView):
     @classmethod
     @ModelView.button
     def end_assessment(cls, assessments):
-        
         assessment_id = assessments[0]
 
         # Change the state of the assessment to "Done"
@@ -271,7 +269,6 @@ class PatientSESAssessment(ModelSQL, ModelView):
             'state': 'done',
             'signed_by': signing_hp,
             })
-        
 
     def patient_age_at_assessment(self, name):
         if (self.patient.name.dob and self.assessment_date):
@@ -309,7 +306,8 @@ class GnuHealthPatient(ModelSQL, ModelView):
     __name__ = 'gnuhealth.patient'
 
 
-    occupation = fields.Function(fields.Many2One('gnuhealth.occupation','Occupation'), 'get_patient_occupation')
+    occupation = fields.Function(fields.Many2One('gnuhealth.occupation'
+        ,'Occupation'), 'get_patient_occupation')
 
     education = fields.Function(fields.Selection([
         (None, ''),
@@ -319,7 +317,8 @@ class GnuHealthPatient(ModelSQL, ModelView):
         ('3', 'Incomplete Secondary School'),
         ('4', 'Secondary School'),
         ('5', 'University'),
-        ], 'Education Level', help="Education Level", sort=False), 'get_patient_education')
+        ], 'Education Level', help="Education Level", sort=False),
+        'get_patient_education')
 
 
     housing = fields.Function(fields.Selection([
@@ -329,7 +328,18 @@ class GnuHealthPatient(ModelSQL, ModelView):
         ('2', 'Comfortable and good sanitary conditions'),
         ('3', 'Roomy and excellent sanitary conditions'),
         ('4', 'Luxury and excellent sanitary conditions'),
-        ], 'Housing conditions', help="Housing and sanitary living conditions", sort=False), 'get_patient_housing')
+        ], 'Housing conditions', help="Housing and sanitary living conditions",
+        sort=False), 'get_patient_housing')
+
+    ses = fields.Function(fields.Selection([
+        (None, ''),
+        ('0', 'Lower'),
+        ('1', 'Lower-middle'),
+        ('2', 'Middle'),
+        ('3', 'Middle-upper'),
+        ('4', 'Higher'),
+        ], 'SES', help="Current Socioeconomic Status", sort=False),
+        'get_patient_ses')
 
 
     ses_assessments = fields.One2Many('gnuhealth.ses.assessment',
@@ -378,3 +388,7 @@ class GnuHealthPatient(ModelSQL, ModelView):
     def get_patient_housing(self, name):
         if (self.name.du):
             return self.name.du.housing
+
+    def get_patient_ses(self, name):
+        if (self.ses_assessments):
+            return self.ses_assessments[0].ses
